import sys
# Want this to fail quick for taking the ~1s that importing sympy takes.
if len(sys.argv) == 1:
        exit('enter a filename')
from sympy import sympify, diff, latex
from sympy.abc import *

'''
Program to solve differentiable functions of one variable.
LHS defines what variable it's a function of.
No format checking right now.

Example of line separated file, one equation per line.

c(x) = r * (cos(x) + sqrt(-1)*sin(x))
a(t) = 1/2 * g * t ** 2
f(x) = sin(x**2) * x^2
h(w) = E ^ (w^4 - (3 * w)^2 + 9)
g(x) = exp(i * pi)
p(j) = csc(j^2)

With that it gives you the derivative, and both the equation and derivative in LaTeX.

'''
def printFmtDerivatives():
    with open(sys.argv[1], 'r') as functionsFile:
        validLineCt = 0
        for equation in functionsFile.read().splitlines():
            if equation == '':
                continue
            if equation[0] == '#':
                continue

            equationSplit            = equation.replace('^', '**').split('=')
            leftHand                 = equationSplit[0].strip()
            rightHand                = equationSplit[1].strip()

            differentiableExpression = sympify(rightHand)
            differentiableVariable   = sympify(leftHand[2])

            derivative               = diff(differentiableExpression, differentiableVariable)

            equationOutput           = f'{leftHand}{" " * 7}= {rightHand}'
            derivativeOutput         = f'd[{leftHand}]/d{differentiableVariable} = {derivative}'
            equationLatex            = latex(differentiableExpression)
            derivativeLatex          = latex(derivative)
            
            print(f'({validLineCt+1})')
            print(f'\t{equationOutput}')
            print(f'\t{derivativeOutput}')
            print()
            print(f'\tTeX fnc.{" " * 5}{equationLatex}')
            print(f'\tTeX deriv.{" " * 3}{derivativeLatex}')

            validLineCt += 1


def main():
    
    printFmtDerivatives()

if __name__ == '__main__':
    main()


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['handyderivatives']

package_data = \
{'': ['*']}

install_requires = \
['sympy>=1.7.1,<2.0.0']

entry_points = \
{'console_scripts': ['handyderivatives = handyderivatives:main']}

setup_kwargs = {
    'name': 'handyderivatives',
    'version': '1.2.2',
    'description': 'A simple little program to batch process some basic calc stuff.',
    'long_description': '# handyderivatives\n\nInstall with pip for the easiest use.\n\n`pip install handyderivatives`\n\n[https://pypi.org/project/handyderivatives/](https://pypi.org/project/handyderivatives/)\n\n## Running it\n`handyderivatives functions.txt`\n\n## How to use it\nIt gets the derivatives for differentiable functions of a single variable.\n\nEdit a file that looks like this. \n\n![Placeholder](https://raw.githubusercontent.com/Fitzy1293/handyderivatives/main/file.png)\n\nTo get output that looks like this. LaTex output is included.\n\n**If you install with pip just run handyderivatives, this image was from before it was published.**\n\n![Placeholder](https://raw.githubusercontent.com/Fitzy1293/handyderivatives/main/output.png)\n',
    'author': 'fitzy1293',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/fitzy1293/handyderivatives',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3,<4',
}


setup(**setup_kwargs)
